( cd opt/kde/share/doc/HTML/sk/kdf ; rm -rf common )
( cd opt/kde/share/doc/HTML/sk/kdf ; ln -sf /opt/kde/share/doc/HTML/sk/common common )
( cd opt/kde/share/doc/HTML/sk/kdm ; rm -rf common )
( cd opt/kde/share/doc/HTML/sk/kdm ; ln -sf /opt/kde/share/doc/HTML/sk/common common )
( cd opt/kde/share/doc/HTML/sk/amor ; rm -rf common )
( cd opt/kde/share/doc/HTML/sk/amor ; ln -sf /opt/kde/share/doc/HTML/sk/common common )
( cd opt/kde/share/doc/HTML/sk/kate ; rm -rf common )
( cd opt/kde/share/doc/HTML/sk/kate ; ln -sf /opt/kde/share/doc/HTML/sk/common common )
( cd opt/kde/share/doc/HTML/sk/kdvi ; rm -rf common )
( cd opt/kde/share/doc/HTML/sk/kdvi ; ln -sf /opt/kde/share/doc/HTML/sk/common common )
( cd opt/kde/share/doc/HTML/sk/kodo ; rm -rf common )
( cd opt/kde/share/doc/HTML/sk/kodo ; ln -sf /opt/kde/share/doc/HTML/sk/common common )
( cd opt/kde/share/doc/HTML/sk/krfb ; rm -rf common )
( cd opt/kde/share/doc/HTML/sk/krfb ; ln -sf /opt/kde/share/doc/HTML/sk/common common )
( cd opt/kde/share/doc/HTML/sk/ksim ; rm -rf common )
( cd opt/kde/share/doc/HTML/sk/ksim ; ln -sf /opt/kde/share/doc/HTML/sk/common common )
( cd opt/kde/share/doc/HTML/sk/katomic ; rm -rf common )
( cd opt/kde/share/doc/HTML/sk/katomic ; ln -sf /opt/kde/share/doc/HTML/sk/common common )
( cd opt/kde/share/doc/HTML/sk/ksysguard ; rm -rf common )
( cd opt/kde/share/doc/HTML/sk/ksysguard ; ln -sf /opt/kde/share/doc/HTML/sk/common common )
( cd opt/kde/share/doc/HTML/sk/kbounce ; rm -rf common )
( cd opt/kde/share/doc/HTML/sk/kbounce ; ln -sf /opt/kde/share/doc/HTML/sk/common common )
( cd opt/kde/share/doc/HTML/sk/kbattleship ; rm -rf common )
( cd opt/kde/share/doc/HTML/sk/kbattleship ; ln -sf /opt/kde/share/doc/HTML/sk/common common )
( cd opt/kde/share/doc/HTML/sk/kaboodle ; rm -rf common )
( cd opt/kde/share/doc/HTML/sk/kaboodle ; ln -sf /opt/kde/share/doc/HTML/sk/common common )
( cd opt/kde/share/doc/HTML/sk/kpercentage ; rm -rf common )
( cd opt/kde/share/doc/HTML/sk/kpercentage ; ln -sf /opt/kde/share/doc/HTML/sk/common common )
( cd opt/kde/share/doc/HTML/sk/kdesu ; rm -rf common )
( cd opt/kde/share/doc/HTML/sk/kdesu ; ln -sf /opt/kde/share/doc/HTML/sk/common common )
( cd opt/kde/share/doc/HTML/sk/kfind ; rm -rf common )
( cd opt/kde/share/doc/HTML/sk/kfind ; ln -sf /opt/kde/share/doc/HTML/sk/common common )
( cd opt/kde/share/doc/HTML/sk/kmoon ; rm -rf common )
( cd opt/kde/share/doc/HTML/sk/kmoon ; ln -sf /opt/kde/share/doc/HTML/sk/common common )
( cd opt/kde/share/doc/HTML/sk/ksame ; rm -rf common )
( cd opt/kde/share/doc/HTML/sk/ksame ; ln -sf /opt/kde/share/doc/HTML/sk/common common )
( cd opt/kde/share/doc/HTML/sk/ktron ; rm -rf common )
( cd opt/kde/share/doc/HTML/sk/ktron ; ln -sf /opt/kde/share/doc/HTML/sk/common common )
( cd opt/kde/share/doc/HTML/sk/kwin4 ; rm -rf common )
( cd opt/kde/share/doc/HTML/sk/kwin4 ; ln -sf /opt/kde/share/doc/HTML/sk/common common )
( cd opt/kde/share/doc/HTML/sk/lskat ; rm -rf common )
( cd opt/kde/share/doc/HTML/sk/lskat ; ln -sf /opt/kde/share/doc/HTML/sk/common common )
( cd opt/kde/share/doc/HTML/sk/kcoloredit ; rm -rf common )
( cd opt/kde/share/doc/HTML/sk/kcoloredit ; ln -sf /opt/kde/share/doc/HTML/sk/common common )
( cd opt/kde/share/doc/HTML/sk/klipper ; rm -rf common )
( cd opt/kde/share/doc/HTML/sk/klipper ; ln -sf /opt/kde/share/doc/HTML/sk/common common )
( cd opt/kde/share/doc/HTML/sk/kompare ; rm -rf common )
( cd opt/kde/share/doc/HTML/sk/kompare ; ln -sf /opt/kde/share/doc/HTML/sk/common common )
( cd opt/kde/share/doc/HTML/sk/khelpcenter/faq ; rm -rf common )
( cd opt/kde/share/doc/HTML/sk/khelpcenter/faq ; ln -sf /opt/kde/share/doc/HTML/sk/common common )
( cd opt/kde/share/doc/HTML/sk/khelpcenter/quickstart ; rm -rf common )
( cd opt/kde/share/doc/HTML/sk/khelpcenter/quickstart ; ln -sf /opt/kde/share/doc/HTML/sk/common common )
( cd opt/kde/share/doc/HTML/sk/khelpcenter/glossary ; rm -rf common )
( cd opt/kde/share/doc/HTML/sk/khelpcenter/glossary ; ln -sf /opt/kde/share/doc/HTML/sk/common common )
( cd opt/kde/share/doc/HTML/sk/khelpcenter ; rm -rf common )
( cd opt/kde/share/doc/HTML/sk/khelpcenter ; ln -sf /opt/kde/share/doc/HTML/sk/common common )
( cd opt/kde/share/doc/HTML/sk/khelpcenter/userguide ; rm -rf common )
( cd opt/kde/share/doc/HTML/sk/khelpcenter/userguide ; ln -sf /opt/kde/share/doc/HTML/sk/common common )
( cd opt/kde/share/doc/HTML/sk/khelpcenter/visualdict ; rm -rf common )
( cd opt/kde/share/doc/HTML/sk/khelpcenter/visualdict ; ln -sf /opt/kde/share/doc/HTML/sk/common common )
( cd opt/kde/share/doc/HTML/sk/kshisen ; rm -rf common )
( cd opt/kde/share/doc/HTML/sk/kshisen ; ln -sf /opt/kde/share/doc/HTML/sk/common common )
( cd opt/kde/share/doc/HTML/sk/ksirtet ; rm -rf common )
( cd opt/kde/share/doc/HTML/sk/ksirtet ; ln -sf /opt/kde/share/doc/HTML/sk/common common )
( cd opt/kde/share/doc/HTML/sk/konquest ; rm -rf common )
( cd opt/kde/share/doc/HTML/sk/konquest ; ln -sf /opt/kde/share/doc/HTML/sk/common common )
( cd opt/kde/share/doc/HTML/sk/kweather ; rm -rf common )
( cd opt/kde/share/doc/HTML/sk/kweather ; ln -sf /opt/kde/share/doc/HTML/sk/common common )
( cd opt/kde/share/doc/HTML/sk/kbugbuster ; rm -rf common )
( cd opt/kde/share/doc/HTML/sk/kbugbuster ; ln -sf /opt/kde/share/doc/HTML/sk/common common )
( cd opt/kde/share/doc/HTML/sk/kmenuedit ; rm -rf common )
( cd opt/kde/share/doc/HTML/sk/kmenuedit ; ln -sf /opt/kde/share/doc/HTML/sk/common common )
( cd opt/kde/share/doc/HTML/sk/kioslave ; rm -rf common )
( cd opt/kde/share/doc/HTML/sk/kioslave ; ln -sf /opt/kde/share/doc/HTML/sk/common common )
( cd opt/kde/share/doc/HTML/sk/kbackgammon ; rm -rf common )
( cd opt/kde/share/doc/HTML/sk/kbackgammon ; ln -sf /opt/kde/share/doc/HTML/sk/common common )
( cd opt/kde/share/doc/HTML/sk/kaddressbook ; rm -rf common )
( cd opt/kde/share/doc/HTML/sk/kaddressbook ; ln -sf /opt/kde/share/doc/HTML/sk/common common )
( cd opt/kde/share/doc/HTML/sk/common ; rm -rf fdl-license )
( cd opt/kde/share/doc/HTML/sk/common ; ln -sf ../../en/common/fdl-license fdl-license )
( cd opt/kde/share/doc/HTML/sk/common ; rm -rf qpl-license.html )
( cd opt/kde/share/doc/HTML/sk/common ; ln -sf ../../en/common/qpl-license.html qpl-license.html )
( cd opt/kde/share/doc/HTML/sk/common ; rm -rf x11-license.html )
( cd opt/kde/share/doc/HTML/sk/common ; ln -sf ../../en/common/x11-license.html x11-license.html )
( cd opt/kde/share/doc/HTML/sk/common ; rm -rf 1.png )
( cd opt/kde/share/doc/HTML/sk/common ; ln -sf ../../en/common/1.png 1.png )
( cd opt/kde/share/doc/HTML/sk/common ; rm -rf xml.dcl )
( cd opt/kde/share/doc/HTML/sk/common ; ln -sf ../../en/common/xml.dcl xml.dcl )
( cd opt/kde/share/doc/HTML/sk/common ; rm -rf 2.png )
( cd opt/kde/share/doc/HTML/sk/common ; ln -sf ../../en/common/2.png 2.png )
( cd opt/kde/share/doc/HTML/sk/common ; rm -rf 3.png )
( cd opt/kde/share/doc/HTML/sk/common ; ln -sf ../../en/common/3.png 3.png )
( cd opt/kde/share/doc/HTML/sk/common ; rm -rf 4.png )
( cd opt/kde/share/doc/HTML/sk/common ; ln -sf ../../en/common/4.png 4.png )
( cd opt/kde/share/doc/HTML/sk/common ; rm -rf 5.png )
( cd opt/kde/share/doc/HTML/sk/common ; ln -sf ../../en/common/5.png 5.png )
( cd opt/kde/share/doc/HTML/sk/common ; rm -rf 6.png )
( cd opt/kde/share/doc/HTML/sk/common ; ln -sf ../../en/common/6.png 6.png )
( cd opt/kde/share/doc/HTML/sk/common ; rm -rf 7.png )
( cd opt/kde/share/doc/HTML/sk/common ; ln -sf ../../en/common/7.png 7.png )
( cd opt/kde/share/doc/HTML/sk/common ; rm -rf 8.png )
( cd opt/kde/share/doc/HTML/sk/common ; ln -sf ../../en/common/8.png 8.png )
( cd opt/kde/share/doc/HTML/sk/common ; rm -rf 9.png )
( cd opt/kde/share/doc/HTML/sk/common ; ln -sf ../../en/common/9.png 9.png )
( cd opt/kde/share/doc/HTML/sk/common ; rm -rf headerbg.png )
( cd opt/kde/share/doc/HTML/sk/common ; ln -sf ../../en/common/headerbg.png headerbg.png )
( cd opt/kde/share/doc/HTML/sk/common ; rm -rf gpl-license.html )
( cd opt/kde/share/doc/HTML/sk/common ; ln -sf ../../en/common/gpl-license.html gpl-license.html )
( cd opt/kde/share/doc/HTML/sk/common ; rm -rf mainheader.html )
( cd opt/kde/share/doc/HTML/sk/common ; ln -sf ../../en/common/mainheader.html mainheader.html )
( cd opt/kde/share/doc/HTML/sk/common ; rm -rf grad.png )
( cd opt/kde/share/doc/HTML/sk/common ; ln -sf ../../en/common/grad.png grad.png )
( cd opt/kde/share/doc/HTML/sk/common ; rm -rf kde-web.css )
( cd opt/kde/share/doc/HTML/sk/common ; ln -sf ../../en/common/kde-web.css kde-web.css )
( cd opt/kde/share/doc/HTML/sk/common ; rm -rf kde_logo_bg.png )
( cd opt/kde/share/doc/HTML/sk/common ; ln -sf ../../en/common/kde_logo_bg.png kde_logo_bg.png )
( cd opt/kde/share/doc/HTML/sk/common ; rm -rf lgpl-license.html )
( cd opt/kde/share/doc/HTML/sk/common ; ln -sf ../../en/common/lgpl-license.html lgpl-license.html )
( cd opt/kde/share/doc/HTML/sk/common ; rm -rf doxygen.css )
( cd opt/kde/share/doc/HTML/sk/common ; ln -sf ../../en/common/doxygen.css doxygen.css )
( cd opt/kde/share/doc/HTML/sk/common ; rm -rf web-doctop.png )
( cd opt/kde/share/doc/HTML/sk/common ; ln -sf ../../en/common/web-doctop.png web-doctop.png )
( cd opt/kde/share/doc/HTML/sk/common ; rm -rf kde-default.css )
( cd opt/kde/share/doc/HTML/sk/common ; ln -sf ../../en/common/kde-default.css kde-default.css )
( cd opt/kde/share/doc/HTML/sk/common ; rm -rf kmenu.png )
( cd opt/kde/share/doc/HTML/sk/common ; ln -sf ../../en/common/kmenu.png kmenu.png )
( cd opt/kde/share/doc/HTML/sk/common ; rm -rf footer.html )
( cd opt/kde/share/doc/HTML/sk/common ; ln -sf ../../en/common/footer.html footer.html )
( cd opt/kde/share/doc/HTML/sk/common ; rm -rf kde-common.css )
( cd opt/kde/share/doc/HTML/sk/common ; ln -sf ../../en/common/kde-common.css kde-common.css )
( cd opt/kde/share/doc/HTML/sk/common ; rm -rf appheader.html )
( cd opt/kde/share/doc/HTML/sk/common ; ln -sf ../../en/common/appheader.html appheader.html )
( cd opt/kde/share/doc/HTML/sk/common ; rm -rf doctop1.png )
( cd opt/kde/share/doc/HTML/sk/common ; ln -sf ../../en/common/doctop1.png doctop1.png )
( cd opt/kde/share/doc/HTML/sk/common ; rm -rf doctop2.png )
( cd opt/kde/share/doc/HTML/sk/common ; ln -sf ../../en/common/doctop2.png doctop2.png )
( cd opt/kde/share/doc/HTML/sk/common ; rm -rf shadow.png )
( cd opt/kde/share/doc/HTML/sk/common ; ln -sf ../../en/common/shadow.png shadow.png )
( cd opt/kde/share/doc/HTML/sk/common ; rm -rf kde_logo.png )
( cd opt/kde/share/doc/HTML/sk/common ; ln -sf ../../en/common/kde_logo.png kde_logo.png )
( cd opt/kde/share/doc/HTML/sk/common ; rm -rf docheadergears.png )
( cd opt/kde/share/doc/HTML/sk/common ; ln -sf ../../en/common/docheadergears.png docheadergears.png )
( cd opt/kde/share/doc/HTML/sk/common ; rm -rf fdl-license.html )
( cd opt/kde/share/doc/HTML/sk/common ; ln -sf ../../en/common/fdl-license.html fdl-license.html )
( cd opt/kde/share/doc/HTML/sk/common ; rm -rf doctop1a.png )
( cd opt/kde/share/doc/HTML/sk/common ; ln -sf ../../en/common/doctop1a.png doctop1a.png )
( cd opt/kde/share/doc/HTML/sk/common ; rm -rf 10.png )
( cd opt/kde/share/doc/HTML/sk/common ; ln -sf ../../en/common/10.png 10.png )
( cd opt/kde/share/doc/HTML/sk/common ; rm -rf doctop1b.png )
( cd opt/kde/share/doc/HTML/sk/common ; ln -sf ../../en/common/doctop1b.png doctop1b.png )
( cd opt/kde/share/doc/HTML/sk/common ; rm -rf lgpl-license )
( cd opt/kde/share/doc/HTML/sk/common ; ln -sf ../../en/common/lgpl-license lgpl-license )
( cd opt/kde/share/doc/HTML/sk/common ; rm -rf mainfooter.html )
( cd opt/kde/share/doc/HTML/sk/common ; ln -sf ../../en/common/mainfooter.html mainfooter.html )
( cd opt/kde/share/doc/HTML/sk/common ; rm -rf bottom1.png )
( cd opt/kde/share/doc/HTML/sk/common ; ln -sf ../../en/common/bottom1.png bottom1.png )
( cd opt/kde/share/doc/HTML/sk/common ; rm -rf bottom2.png )
( cd opt/kde/share/doc/HTML/sk/common ; ln -sf ../../en/common/bottom2.png bottom2.png )
( cd opt/kde/share/doc/HTML/sk/common ; rm -rf header.html )
( cd opt/kde/share/doc/HTML/sk/common ; ln -sf ../../en/common/header.html header.html )
( cd opt/kde/share/doc/HTML/sk/common ; rm -rf gpl-license )
( cd opt/kde/share/doc/HTML/sk/common ; ln -sf ../../en/common/gpl-license gpl-license )
( cd opt/kde/share/doc/HTML/sk/common ; rm -rf kde-localised.css.template )
( cd opt/kde/share/doc/HTML/sk/common ; ln -sf ../../en/common/kde-localised.css.template kde-localised.css.template )
( cd opt/kde/share/doc/HTML/sk/common ; rm -rf bsd-license.html )
( cd opt/kde/share/doc/HTML/sk/common ; ln -sf ../../en/common/bsd-license.html bsd-license.html )
( cd opt/kde/share/doc/HTML/sk/common ; rm -rf web-docbottom.png )
( cd opt/kde/share/doc/HTML/sk/common ; ln -sf ../../en/common/web-docbottom.png web-docbottom.png )
( cd opt/kde/share/doc/HTML/sk/common ; rm -rf artistic-license.html )
( cd opt/kde/share/doc/HTML/sk/common ; ln -sf ../../en/common/artistic-license.html artistic-license.html )
( cd opt/kde/share/doc/HTML/sk/kcontrol/kdm ; rm -rf common )
( cd opt/kde/share/doc/HTML/sk/kcontrol/kdm ; ln -sf /opt/kde/share/doc/HTML/sk/common common )
( cd opt/kde/share/doc/HTML/sk/kcontrol/smb ; rm -rf common )
( cd opt/kde/share/doc/HTML/sk/kcontrol/smb ; ln -sf /opt/kde/share/doc/HTML/sk/common common )
( cd opt/kde/share/doc/HTML/sk/kcontrol/spellchecking ; rm -rf common )
( cd opt/kde/share/doc/HTML/sk/kcontrol/spellchecking ; ln -sf /opt/kde/share/doc/HTML/sk/common common )
( cd opt/kde/share/doc/HTML/sk/kcontrol/bell ; rm -rf common )
( cd opt/kde/share/doc/HTML/sk/kcontrol/bell ; ln -sf /opt/kde/share/doc/HTML/sk/common common )
( cd opt/kde/share/doc/HTML/sk/kcontrol/arts ; rm -rf common )
( cd opt/kde/share/doc/HTML/sk/kcontrol/arts ; ln -sf /opt/kde/share/doc/HTML/sk/common common )
( cd opt/kde/share/doc/HTML/sk/kcontrol/keys ; rm -rf common )
( cd opt/kde/share/doc/HTML/sk/kcontrol/keys ; ln -sf /opt/kde/share/doc/HTML/sk/common common )
( cd opt/kde/share/doc/HTML/sk/kcontrol/powerctrl ; rm -rf common )
( cd opt/kde/share/doc/HTML/sk/kcontrol/powerctrl ; ln -sf /opt/kde/share/doc/HTML/sk/common common )
( cd opt/kde/share/doc/HTML/sk/kcontrol/kalarmd ; rm -rf common )
( cd opt/kde/share/doc/HTML/sk/kcontrol/kalarmd ; ln -sf /opt/kde/share/doc/HTML/sk/common common )
( cd opt/kde/share/doc/HTML/sk/kcontrol/cookies ; rm -rf common )
( cd opt/kde/share/doc/HTML/sk/kcontrol/cookies ; ln -sf /opt/kde/share/doc/HTML/sk/common common )
( cd opt/kde/share/doc/HTML/sk/kcontrol/filetypes ; rm -rf common )
( cd opt/kde/share/doc/HTML/sk/kcontrol/filetypes ; ln -sf /opt/kde/share/doc/HTML/sk/common common )
( cd opt/kde/share/doc/HTML/sk/kcontrol/desktop ; rm -rf common )
( cd opt/kde/share/doc/HTML/sk/kcontrol/desktop ; ln -sf /opt/kde/share/doc/HTML/sk/common common )
( cd opt/kde/share/doc/HTML/sk/kcontrol/cache ; rm -rf common )
( cd opt/kde/share/doc/HTML/sk/kcontrol/cache ; ln -sf /opt/kde/share/doc/HTML/sk/common common )
( cd opt/kde/share/doc/HTML/sk/kcontrol/clock ; rm -rf common )
( cd opt/kde/share/doc/HTML/sk/kcontrol/clock ; ln -sf /opt/kde/share/doc/HTML/sk/common common )
( cd opt/kde/share/doc/HTML/sk/kcontrol/email ; rm -rf common )
( cd opt/kde/share/doc/HTML/sk/kcontrol/email ; ln -sf /opt/kde/share/doc/HTML/sk/common common )
( cd opt/kde/share/doc/HTML/sk/kcontrol/fonts ; rm -rf common )
( cd opt/kde/share/doc/HTML/sk/kcontrol/fonts ; ln -sf /opt/kde/share/doc/HTML/sk/common common )
( cd opt/kde/share/doc/HTML/sk/kcontrol/icons ; rm -rf common )
( cd opt/kde/share/doc/HTML/sk/kcontrol/icons ; ln -sf /opt/kde/share/doc/HTML/sk/common common )
( cd opt/kde/share/doc/HTML/sk/kcontrol/khtml ; rm -rf common )
( cd opt/kde/share/doc/HTML/sk/kcontrol/khtml ; ln -sf /opt/kde/share/doc/HTML/sk/common common )
( cd opt/kde/share/doc/HTML/sk/kcontrol/filemanager ; rm -rf common )
( cd opt/kde/share/doc/HTML/sk/kcontrol/filemanager ; ln -sf /opt/kde/share/doc/HTML/sk/common common )
( cd opt/kde/share/doc/HTML/sk/kcontrol/mouse ; rm -rf common )
( cd opt/kde/share/doc/HTML/sk/kcontrol/mouse ; ln -sf /opt/kde/share/doc/HTML/sk/common common )
( cd opt/kde/share/doc/HTML/sk/kcontrol/panel ; rm -rf common )
( cd opt/kde/share/doc/HTML/sk/kcontrol/panel ; ln -sf /opt/kde/share/doc/HTML/sk/common common )
( cd opt/kde/share/doc/HTML/sk/kcontrol/proxy ; rm -rf common )
( cd opt/kde/share/doc/HTML/sk/kcontrol/proxy ; ln -sf /opt/kde/share/doc/HTML/sk/common common )
( cd opt/kde/share/doc/HTML/sk/kcontrol/kmixcfg ; rm -rf common )
( cd opt/kde/share/doc/HTML/sk/kcontrol/kmixcfg ; ln -sf /opt/kde/share/doc/HTML/sk/common common )
( cd opt/kde/share/doc/HTML/sk/kcontrol/lanbrowser ; rm -rf common )
( cd opt/kde/share/doc/HTML/sk/kcontrol/lanbrowser ; ln -sf /opt/kde/share/doc/HTML/sk/common common )
( cd opt/kde/share/doc/HTML/sk/kcontrol/passwords ; rm -rf common )
( cd opt/kde/share/doc/HTML/sk/kcontrol/passwords ; ln -sf /opt/kde/share/doc/HTML/sk/common common )
( cd opt/kde/share/doc/HTML/sk/kcontrol/ebrowsing ; rm -rf common )
( cd opt/kde/share/doc/HTML/sk/kcontrol/ebrowsing ; ln -sf /opt/kde/share/doc/HTML/sk/common common )
( cd opt/kde/share/doc/HTML/sk/kcontrol/background ; rm -rf common )
( cd opt/kde/share/doc/HTML/sk/kcontrol/background ; ln -sf /opt/kde/share/doc/HTML/sk/common common )
( cd opt/kde/share/doc/HTML/sk/kcontrol/kcmaccess ; rm -rf common )
( cd opt/kde/share/doc/HTML/sk/kcontrol/kcmaccess ; ln -sf /opt/kde/share/doc/HTML/sk/common common )
( cd opt/kde/share/doc/HTML/sk/kcontrol/colors ; rm -rf common )
( cd opt/kde/share/doc/HTML/sk/kcontrol/colors ; ln -sf /opt/kde/share/doc/HTML/sk/common common )
( cd opt/kde/share/doc/HTML/sk/kcontrol ; rm -rf common )
( cd opt/kde/share/doc/HTML/sk/kcontrol ; ln -sf /opt/kde/share/doc/HTML/sk/common common )
( cd opt/kde/share/doc/HTML/sk/kcontrol/crypto ; rm -rf common )
( cd opt/kde/share/doc/HTML/sk/kcontrol/crypto ; ln -sf /opt/kde/share/doc/HTML/sk/common common )
( cd opt/kde/share/doc/HTML/sk/kcontrol/energy ; rm -rf common )
( cd opt/kde/share/doc/HTML/sk/kcontrol/energy ; ln -sf /opt/kde/share/doc/HTML/sk/common common )
( cd opt/kde/share/doc/HTML/sk/kcontrol/kcmstyle ; rm -rf common )
( cd opt/kde/share/doc/HTML/sk/kcontrol/kcmstyle ; ln -sf /opt/kde/share/doc/HTML/sk/common common )
( cd opt/kde/share/doc/HTML/sk/kcontrol/netpref ; rm -rf common )
( cd opt/kde/share/doc/HTML/sk/kcontrol/netpref ; ln -sf /opt/kde/share/doc/HTML/sk/common common )
( cd opt/kde/share/doc/HTML/sk/kcontrol/kcmlaunch ; rm -rf common )
( cd opt/kde/share/doc/HTML/sk/kcontrol/kcmlaunch ; ln -sf /opt/kde/share/doc/HTML/sk/common common )
( cd opt/kde/share/doc/HTML/sk/kcontrol/kcmktalkd ; rm -rf common )
( cd opt/kde/share/doc/HTML/sk/kcontrol/kcmktalkd ; ln -sf /opt/kde/share/doc/HTML/sk/common common )
( cd opt/kde/share/doc/HTML/sk/kcontrol/kcmcss ; rm -rf common )
( cd opt/kde/share/doc/HTML/sk/kcontrol/kcmcss ; ln -sf /opt/kde/share/doc/HTML/sk/common common )
( cd opt/kde/share/doc/HTML/sk/kcontrol/laptop ; rm -rf common )
( cd opt/kde/share/doc/HTML/sk/kcontrol/laptop ; ln -sf /opt/kde/share/doc/HTML/sk/common common )
( cd opt/kde/share/doc/HTML/sk/kcontrol/kxmlrpcd ; rm -rf common )
( cd opt/kde/share/doc/HTML/sk/kcontrol/kxmlrpcd ; ln -sf /opt/kde/share/doc/HTML/sk/common common )
( cd opt/kde/share/doc/HTML/sk/kcontrol/kcmnotify ; rm -rf common )
( cd opt/kde/share/doc/HTML/sk/kcontrol/kcmnotify ; ln -sf /opt/kde/share/doc/HTML/sk/common common )
( cd opt/kde/share/doc/HTML/sk/kcontrol/kcmsmserver ; rm -rf common )
( cd opt/kde/share/doc/HTML/sk/kcontrol/kcmsmserver ; ln -sf /opt/kde/share/doc/HTML/sk/common common )
( cd opt/kde/share/doc/HTML/sk/kcontrol/screensaver ; rm -rf common )
( cd opt/kde/share/doc/HTML/sk/kcontrol/screensaver ; ln -sf /opt/kde/share/doc/HTML/sk/common common )
( cd opt/kde/share/doc/HTML/sk/kcontrol/windowmanagement ; rm -rf common )
( cd opt/kde/share/doc/HTML/sk/kcontrol/windowmanagement ; ln -sf /opt/kde/share/doc/HTML/sk/common common )
( cd opt/kde/share/doc/HTML/sk/kcontrol/kwindecoration ; rm -rf common )
( cd opt/kde/share/doc/HTML/sk/kcontrol/kwindecoration ; ln -sf /opt/kde/share/doc/HTML/sk/common common )
( cd opt/kde/share/doc/HTML/sk/kcontrol/kcmkonsole ; rm -rf common )
( cd opt/kde/share/doc/HTML/sk/kcontrol/kcmkonsole ; ln -sf /opt/kde/share/doc/HTML/sk/common common )
( cd opt/kde/share/doc/HTML/sk/kcontrol/language ; rm -rf common )
( cd opt/kde/share/doc/HTML/sk/kcontrol/language ; ln -sf /opt/kde/share/doc/HTML/sk/common common )
( cd opt/kde/share/doc/HTML/sk/kcontrol/useragent ; rm -rf common )
( cd opt/kde/share/doc/HTML/sk/kcontrol/useragent ; ln -sf /opt/kde/share/doc/HTML/sk/common common )
( cd opt/kde/share/doc/HTML/sk/kcontrol/helpindex ; rm -rf common )
( cd opt/kde/share/doc/HTML/sk/kcontrol/helpindex ; ln -sf /opt/kde/share/doc/HTML/sk/common common )
( cd opt/kde/share/doc/HTML/sk/kcontrol/kcmlowbatcrit ; rm -rf common )
( cd opt/kde/share/doc/HTML/sk/kcontrol/kcmlowbatcrit ; ln -sf /opt/kde/share/doc/HTML/sk/common common )
( cd opt/kde/share/doc/HTML/sk/kcontrol/kcmlowbatwarn ; rm -rf common )
( cd opt/kde/share/doc/HTML/sk/kcontrol/kcmlowbatwarn ; ln -sf /opt/kde/share/doc/HTML/sk/common common )
( cd opt/kde/share/doc/HTML/sk/kcontrol/keyboard ; rm -rf common )
( cd opt/kde/share/doc/HTML/sk/kcontrol/keyboard ; ln -sf /opt/kde/share/doc/HTML/sk/common common )
( cd opt/kde/share/doc/HTML/sk/kcontrol/kcmtaskbar ; rm -rf common )
( cd opt/kde/share/doc/HTML/sk/kcontrol/kcmtaskbar ; ln -sf /opt/kde/share/doc/HTML/sk/common common )
( cd opt/kde/share/doc/HTML/sk/kcontrol/kcmfontinst ; rm -rf common )
( cd opt/kde/share/doc/HTML/sk/kcontrol/kcmfontinst ; ln -sf /opt/kde/share/doc/HTML/sk/common common )
( cd opt/kde/share/doc/HTML/sk/kicker-applets ; rm -rf common )
( cd opt/kde/share/doc/HTML/sk/kicker-applets ; ln -sf /opt/kde/share/doc/HTML/sk/common common )
( cd opt/kde/share/doc/HTML/sk/konq-plugins ; rm -rf common )
( cd opt/kde/share/doc/HTML/sk/konq-plugins ; ln -sf /opt/kde/share/doc/HTML/sk/common common )
( cd opt/kde/share/doc/HTML/sk/kamera ; rm -rf common )
( cd opt/kde/share/doc/HTML/sk/kamera ; ln -sf /opt/kde/share/doc/HTML/sk/common common )
( cd opt/kde/share/doc/HTML/sk/kdeprint ; rm -rf common )
( cd opt/kde/share/doc/HTML/sk/kdeprint ; ln -sf /opt/kde/share/doc/HTML/sk/common common )
( cd opt/kde/share/doc/HTML/sk/kasteroids ; rm -rf common )
( cd opt/kde/share/doc/HTML/sk/kasteroids ; ln -sf /opt/kde/share/doc/HTML/sk/common common )
( cd opt/kde/share/doc/HTML/sk/kicker ; rm -rf common )
( cd opt/kde/share/doc/HTML/sk/kicker ; ln -sf /opt/kde/share/doc/HTML/sk/common common )
( cd opt/kde/share/doc/HTML/sk/klines ; rm -rf common )
( cd opt/kde/share/doc/HTML/sk/klines ; ln -sf /opt/kde/share/doc/HTML/sk/common common )
( cd opt/kde/share/doc/HTML/sk/kmines ; rm -rf common )
( cd opt/kde/share/doc/HTML/sk/kmines ; ln -sf /opt/kde/share/doc/HTML/sk/common common )
( cd opt/kde/share/doc/HTML/sk/kmplot ; rm -rf common )
( cd opt/kde/share/doc/HTML/sk/kmplot ; ln -sf /opt/kde/share/doc/HTML/sk/common common )
( cd opt/kde/share/doc/HTML/sk/kpager ; rm -rf common )
( cd opt/kde/share/doc/HTML/sk/kpager ; ln -sf /opt/kde/share/doc/HTML/sk/common common )
( cd opt/kde/share/doc/HTML/sk/kruler ; rm -rf common )
( cd opt/kde/share/doc/HTML/sk/kruler ; ln -sf /opt/kde/share/doc/HTML/sk/common common )
( cd opt/kde/share/doc/HTML/sk/ksnake ; rm -rf common )
( cd opt/kde/share/doc/HTML/sk/ksnake ; ln -sf /opt/kde/share/doc/HTML/sk/common common )
( cd opt/kde/share/doc/HTML/sk/kspell ; rm -rf common )
( cd opt/kde/share/doc/HTML/sk/kspell ; ln -sf /opt/kde/share/doc/HTML/sk/common common )
( cd opt/kde/share/doc/HTML/sk/ktimer ; rm -rf common )
( cd opt/kde/share/doc/HTML/sk/ktimer ; ln -sf /opt/kde/share/doc/HTML/sk/common common )
( cd opt/kde/share/doc/HTML/sk/kreversi ; rm -rf common )
( cd opt/kde/share/doc/HTML/sk/kreversi ; ln -sf /opt/kde/share/doc/HTML/sk/common common )
( cd opt/kde/share/doc/HTML/sk/kdebugdialog ; rm -rf common )
( cd opt/kde/share/doc/HTML/sk/kdebugdialog ; ln -sf /opt/kde/share/doc/HTML/sk/common common )
( cd opt/kde/share/doc/HTML/sk/kblackbox ; rm -rf common )
( cd opt/kde/share/doc/HTML/sk/kblackbox ; ln -sf /opt/kde/share/doc/HTML/sk/common common )
( cd opt/kde/share/doc/HTML/sk/kcharselect ; rm -rf common )
( cd opt/kde/share/doc/HTML/sk/kcharselect ; ln -sf /opt/kde/share/doc/HTML/sk/common common )
( cd opt/kde/share/doc/HTML/sk/kfouleggs ; rm -rf common )
( cd opt/kde/share/doc/HTML/sk/kfouleggs ; ln -sf /opt/kde/share/doc/HTML/sk/common common )
( cd opt/kde/share/doc/HTML/sk/klickety ; rm -rf common )
( cd opt/kde/share/doc/HTML/sk/klickety ; ln -sf /opt/kde/share/doc/HTML/sk/common common )
( cd opt/kde/share/doc/HTML/sk/kjumpingcube ; rm -rf common )
( cd opt/kde/share/doc/HTML/sk/kjumpingcube ; ln -sf /opt/kde/share/doc/HTML/sk/common common )
( cd opt/kde/share/doc/HTML/sk/kworldclock ; rm -rf common )
( cd opt/kde/share/doc/HTML/sk/kworldclock ; ln -sf /opt/kde/share/doc/HTML/sk/common common )
( cd opt/kde/share/doc/HTML/sk/ksokoban ; rm -rf common )
( cd opt/kde/share/doc/HTML/sk/ksokoban ; ln -sf /opt/kde/share/doc/HTML/sk/common common )
( cd opt/kde/share/doc/HTML/sk/kteatime ; rm -rf common )
( cd opt/kde/share/doc/HTML/sk/kteatime ; ln -sf /opt/kde/share/doc/HTML/sk/common common )
( cd opt/kde/share/doc/HTML/sk/kmathtool ; rm -rf common )
( cd opt/kde/share/doc/HTML/sk/kmathtool ; ln -sf /opt/kde/share/doc/HTML/sk/common common )
( cd opt/kde/share/doc/HTML/sk/kinfocenter/dma ; rm -rf common )
( cd opt/kde/share/doc/HTML/sk/kinfocenter/dma ; ln -sf /opt/kde/share/doc/HTML/sk/common common )
( cd opt/kde/share/doc/HTML/sk/kinfocenter/pci ; rm -rf common )
( cd opt/kde/share/doc/HTML/sk/kinfocenter/pci ; ln -sf /opt/kde/share/doc/HTML/sk/common common )
( cd opt/kde/share/doc/HTML/sk/kinfocenter/usb ; rm -rf common )
( cd opt/kde/share/doc/HTML/sk/kinfocenter/usb ; ln -sf /opt/kde/share/doc/HTML/sk/common common )
( cd opt/kde/share/doc/HTML/sk/kinfocenter/nics ; rm -rf common )
( cd opt/kde/share/doc/HTML/sk/kinfocenter/nics ; ln -sf /opt/kde/share/doc/HTML/sk/common common )
( cd opt/kde/share/doc/HTML/sk/kinfocenter/scsi ; rm -rf common )
( cd opt/kde/share/doc/HTML/sk/kinfocenter/scsi ; ln -sf /opt/kde/share/doc/HTML/sk/common common )
( cd opt/kde/share/doc/HTML/sk/kinfocenter/interrupts ; rm -rf common )
( cd opt/kde/share/doc/HTML/sk/kinfocenter/interrupts ; ln -sf /opt/kde/share/doc/HTML/sk/common common )
( cd opt/kde/share/doc/HTML/sk/kinfocenter/devices ; rm -rf common )
( cd opt/kde/share/doc/HTML/sk/kinfocenter/devices ; ln -sf /opt/kde/share/doc/HTML/sk/common common )
( cd opt/kde/share/doc/HTML/sk/kinfocenter/blockdevices ; rm -rf common )
( cd opt/kde/share/doc/HTML/sk/kinfocenter/blockdevices ; ln -sf /opt/kde/share/doc/HTML/sk/common common )
( cd opt/kde/share/doc/HTML/sk/kinfocenter/xserver ; rm -rf common )
( cd opt/kde/share/doc/HTML/sk/kinfocenter/xserver ; ln -sf /opt/kde/share/doc/HTML/sk/common common )
( cd opt/kde/share/doc/HTML/sk/kinfocenter/samba ; rm -rf common )
( cd opt/kde/share/doc/HTML/sk/kinfocenter/samba ; ln -sf /opt/kde/share/doc/HTML/sk/common common )
( cd opt/kde/share/doc/HTML/sk/kinfocenter/sound ; rm -rf common )
( cd opt/kde/share/doc/HTML/sk/kinfocenter/sound ; ln -sf /opt/kde/share/doc/HTML/sk/common common )
( cd opt/kde/share/doc/HTML/sk/kinfocenter/partitions ; rm -rf common )
( cd opt/kde/share/doc/HTML/sk/kinfocenter/partitions ; ln -sf /opt/kde/share/doc/HTML/sk/common common )
( cd opt/kde/share/doc/HTML/sk/kinfocenter ; rm -rf common )
( cd opt/kde/share/doc/HTML/sk/kinfocenter ; ln -sf /opt/kde/share/doc/HTML/sk/common common )
( cd opt/kde/share/doc/HTML/sk/kinfocenter/memory ; rm -rf common )
( cd opt/kde/share/doc/HTML/sk/kinfocenter/memory ; ln -sf /opt/kde/share/doc/HTML/sk/common common )
( cd opt/kde/share/doc/HTML/sk/kinfocenter/pcmcia ; rm -rf common )
( cd opt/kde/share/doc/HTML/sk/kinfocenter/pcmcia ; ln -sf /opt/kde/share/doc/HTML/sk/common common )
( cd opt/kde/share/doc/HTML/sk/kinfocenter/processor ; rm -rf common )
( cd opt/kde/share/doc/HTML/sk/kinfocenter/processor ; ln -sf /opt/kde/share/doc/HTML/sk/common common )
( cd opt/kde/share/doc/HTML/sk/kinfocenter/ioports ; rm -rf common )
( cd opt/kde/share/doc/HTML/sk/kinfocenter/ioports ; ln -sf /opt/kde/share/doc/HTML/sk/common common )
( cd opt/kde/share/doc/HTML/sk/kinfocenter/protocols ; rm -rf common )
( cd opt/kde/share/doc/HTML/sk/kinfocenter/protocols ; ln -sf /opt/kde/share/doc/HTML/sk/common common )
( cd opt/kde/share/doc/HTML/sk/kate-plugins ; rm -rf common )
( cd opt/kde/share/doc/HTML/sk/kate-plugins ; ln -sf /opt/kde/share/doc/HTML/sk/common common )
( cd opt/kde/share/doc/HTML/sk/konqueror ; rm -rf common )
( cd opt/kde/share/doc/HTML/sk/konqueror ; ln -sf /opt/kde/share/doc/HTML/sk/common common )
( cd opt/kde/share/doc/HTML/sk/atlantik ; rm -rf common )
( cd opt/kde/share/doc/HTML/sk/atlantik ; ln -sf /opt/kde/share/doc/HTML/sk/common common )
